.. _functions:

**************************************
Functions (`baseband_tasks.functions`)
**************************************

`~baseband_tasks.functions` contains general tasks to apply a user-defined
function to a stream, as well as pre-defined implementations for common
functions such as squaring to transform voltages to into intensities.

.. _functions_api:

Reference/API
=============

.. automodapi:: baseband_tasks.functions
   :no-inherited-members:
